==> haskell-sandi-0.4.0-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-sandi.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sandi
version: 0.4.0
id: sandi-0.4.0-B57K7sDz3iD3snvLJmODhs
key: sandi-0.4.0-B57K7sDz3iD3snvLJmODhs
license: BSD3
copyright: Magnus Therning, 2012
maintainer: magnus@therning.org
homepage: http://hackage.haskell.org/package/sandi
synopsis: Data encoding library
description:
    Reasonably fast data encoding library.
category: Codec, Conduit
author: Magnus Therning
exposed: True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.QuotedPrintable Codec.Binary.Uu Codec.Binary.Xx
    Codec.Binary.Yenc Data.Conduit.Codec.Base16
    Data.Conduit.Codec.Base32 Data.Conduit.Codec.Base32Hex
    Data.Conduit.Codec.Base64 Data.Conduit.Codec.Base64Url
    Data.Conduit.Codec.Base85 Data.Conduit.Codec.QuotedPrintable
    Data.Conduit.Codec.Uu Data.Conduit.Codec.Xx Data.Conduit.Codec.Yenc
hidden-modules: Data.Conduit.Codec.Util
abi: 26e1fd9aaaccfac161548c113fa654e9
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/sandi-0.4.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/sandi-0.4.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/sandi-0.4.0
hs-libraries: HSsandi-0.4.0-B57K7sDz3iD3snvLJmODhs
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    conduit-1.2.10-HIC8vE5Ia4HDIPETJJNHDv
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    stringsearch-0.3.6.6-DVhPUcSGzzGLKEmt1U9sof
haddock-interfaces: /usr/share/doc/haskell-sandi/html/sandi.haddock
haddock-html: /usr/share/doc/haskell-sandi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sandi-0.4.0-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-sandi.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sandi
version: 0.4.0
id: sandi-0.4.0-5wlj1R55HeuDUmNs3BD8vs
key: sandi-0.4.0-5wlj1R55HeuDUmNs3BD8vs
license: BSD3
copyright: Magnus Therning, 2012
maintainer: magnus@therning.org
homepage: http://hackage.haskell.org/package/sandi
synopsis: Data encoding library
description:
    Reasonably fast data encoding library.
category: Codec, Conduit
author: Magnus Therning
exposed: True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.QuotedPrintable Codec.Binary.Uu Codec.Binary.Xx
    Codec.Binary.Yenc Data.Conduit.Codec.Base16
    Data.Conduit.Codec.Base32 Data.Conduit.Codec.Base32Hex
    Data.Conduit.Codec.Base64 Data.Conduit.Codec.Base64Url
    Data.Conduit.Codec.Base85 Data.Conduit.Codec.QuotedPrintable
    Data.Conduit.Codec.Uu Data.Conduit.Codec.Xx Data.Conduit.Codec.Yenc
hidden-modules: Data.Conduit.Codec.Util
abi: 1afcf2879249e1cf01fbeb2186ca70da
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/sandi-0.4.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/sandi-0.4.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/sandi-0.4.0
hs-libraries: HSsandi-0.4.0-5wlj1R55HeuDUmNs3BD8vs
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    conduit-1.2.11-5u7YE5Ecuce5vjjIFEkula
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    stringsearch-0.3.6.6-DVhPUcSGzzGLKEmt1U9sof
haddock-interfaces: /usr/share/doc/haskell-sandi/html/sandi.haddock
haddock-html: /usr/share/doc/haskell-sandi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
